# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service
NULL

#' AWS Performance Insights
#'
#' @description
#' AWS Performance Insights enables you to monitor and explore different
#' dimensions of database load based on data captured from a running RDS
#' instance. The guide provides detailed information about Performance
#' Insights data types, parameters and errors. For more information about
#' Performance Insights capabilities see [Using Amazon RDS Performance
#' Insights](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.html)
#' in the *Amazon RDS User Guide*.
#' 
#' The AWS Performance Insights API provides visibility into the
#' performance of your RDS instance, when Performance Insights is enabled
#' for supported engine types. While Amazon CloudWatch provides the
#' authoritative source for AWS service vended monitoring metrics, AWS
#' Performance Insights offers a domain-specific view of database load
#' measured as Average Active Sessions and provided to API consumers as a
#' 2-dimensional time-series dataset. The time dimension of the data
#' provides DB load data for each time point in the queried time range, and
#' each time point decomposes overall load in relation to the requested
#' dimensions, such as SQL, Wait-event, User or Host, measured at that time
#' point.
#'
#' @examples
#' \donttest{svc <- pi()
#' svc$describe_dimension_keys(
#'   Foo = 123
#' )}
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=pi_describe_dimension_keys]{describe_dimension_keys} \tab For a specific time period, retrieve the top N dimension keys for a metric \cr
#'  \link[=pi_get_resource_metrics]{get_resource_metrics} \tab Retrieve Performance Insights metrics for a set of data sources, over a time period
#' }
#'
#' @rdname pi
#' @export
pi <- function() {
  .pi$operations
}

# Private API objects: metadata, handlers, interfaces, etc.
.pi <- list()

.pi$operations <- list()

.pi$metadata <- list(
  service_name = "pi",
  endpoints = list("*" = "pi.{region}.amazonaws.com", "cn-*" = "pi.{region}.amazonaws.com.cn"),
  service_id = "PI",
  api_version = "2018-02-27",
  signing_name = "pi",
  json_version = "1.1",
  target_prefix = "PerformanceInsightsv20180227"
)

.pi$handlers <- new_handlers("jsonrpc", "v4")

.pi$service <- function() {
  new_service(.pi$metadata, .pi$handlers)
}
